Crate codex_agent_extension

Crate codex_agent_extension 

Structs

AgentInvocation
A fully resolved agent invocation.
AgentRun
A spawned agent whose initial turn has been submitted.
AgentRunner
Runs resolved agents in threads forked by the owning ThreadManager.