pub struct AgentRunner { /* private fields */ }Expand description
Runs resolved agents in threads forked by the owning ThreadManager.
Implementations
Sourceimpl AgentRunner
impl AgentRunner
pub fn new(thread_manager: Weak<ThreadManager>) -> Self
Sourcepub async fn start(
&self,
parent_thread_id: ThreadId,
invocation: AgentInvocation,
) -> CodexResult<AgentRun>
pub async fn start( &self, parent_thread_id: ThreadId, invocation: AgentInvocation, ) -> CodexResult<AgentRun>
Starts a resolved agent in a fork of parent_thread_id.